<template>
  <div>
    <BasicTable @register="registerTable">
      <template #toolbar>
        <a-button color="primary" @click="aoaToExcel"> 导出 </a-button>
      </template>
      <!-- <template #action="{ record }">
        <TableAction :actions="[
          {
            icon: 'clarity:info-standard-line',
            tooltip: '报废',
            onClick: handleEdit.bind(null, record),
          },
        ]" />
      </template> -->
    </BasicTable>
    <Loading :loading="compState.loading" :tip="compState.tip" />
    <!-- <WmsItemDrawer @register="registerDrawer" @success="handleSuccess" /> -->
  </div>
</template>
<script lang="ts" setup>
import { reactive } from 'vue';
import { aoaToSheetXlsx } from '/@/components/Excel';
import { BasicTable, useTable, TableAction } from '/@/components/Table';

import { useModal } from '/@/components/Modal';
import { columns, searchFormSchema } from './smt_loading.data';
import { getloadingListByPage } from '/@/api/tigerapi/mes/smt/loading';
import { useGo } from '/@/hooks/web/usePage';
import { Loading } from '/@/components/Loading';
import { useMessage } from '/@/hooks/web/useMessage';
import { useI18n } from '/@/hooks/web/useI18n';
import { SaveSolder } from '/@/api/tigerapi/mes/smt/solder';

const { t } = useI18n();
const { createMessage } = useMessage();
const go = useGo();
const compState = reactive({
  absolute: false,
  loading: false,
  tip: '加载中...',
});
const [registerTable,{getForm,getPaginationRef,reload}] = useTable({
  title: '实时上料信息',
  api: getloadingListByPage,
  columns,
  formConfig: {
    labelWidth: 120,
    schemas: searchFormSchema,
  },
  // actionColumn: {
  //   width: 80,
  //   title: '操作',
  //   dataIndex: 'action',
  //   slots: { customRender: 'action' },
  //   fixed: 'right', //undefined,
  // },
  ellipsis:true,
  useSearchForm: true,
  showTableSetting: false,
  bordered: true,
  showIndexColumn: false,
});
let arr: any[] = [];
//导出
function aoaToExcel() {
   const totals = getPaginationRef().total
  if (totals < 30000) {
    arr = [];
    compState.loading = true;
    const col = getForm().getFieldsValue()
    getloadingListByPage(col).then((res) => {
      res.items.forEach(element => {
        arr.push({
          '工单编码': element.WORK_ORDER,
          '产线线别': element.LINE_CODE,
          '机器编码': element.SMT_CODE,
          '板面': element.PCB_SURFACE,
          '槽位': element.SLOT_NO,
          '飞达类型代码': element.FEEDER_TYPE,
          '飞达代码': element.FEEDER_CODE,
          'Upn': element.SOLDER_UPN,
          '物料代码': element.ITEM_CODE,
          '创建人': element.CREATE_USER,
          '创建时间': element.CREATE_TIME
        });
      });
      const arrHeader = columns.map((column) => column.title);
      const arrData = arr.map((item) => {
        return Object.keys(item).map((key) => item[key]);
      });
      // 保证data顺序与header一致
      if(arr.length<30000){
        aoaToSheetXlsx({
        data: arrData,
        header: arrHeader,
        filename: '实时上料信息.xlsx',
      });
      }else{
        createMessage.error(t('导出数据不能超过三万条，如需要更多的请联系管理员'));
      }
      
      compState.loading = false;

    })

  } else {
    createMessage.error(t('导出数据不能超过三万条，如需要更多的请联系管理员'));
  }


}
//跳转到实时库存
function handleEdit(record: any) {
  //跳转页面
  //go('/WmsItem/' + record.ITEM_CODE);
  const apiAction = SaveSolder(record, true);
  apiAction.then((action) => {
    if (action) {
      if (action.IsSuccessed) {
        createMessage.success(t('已报废成功'));
      }
    } else {
      createMessage.error(action.Message);
    }
  });

}

function handleSuccess() {
  reload();
}
</script>
